@@ -2,7 +2,8 @@
 use strict;
 use warnings;
 
-use if $ENV{USER} eq 'gene', lib => map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-RtMidi-ScorePlayer MIDI-Util);
+use if exists $ENV{USER} && $ENV{USER} eq 'gene', lib => map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-RtMidi-ScorePlayer MIDI-Util);
+
 use MIDI::RtMidi::ScorePlayer ();
 use MIDI::Util qw( setup_score set_chan_patch );
 use Music::Scales qw( get_scale_MIDI );
@@ -26,14 +27,17 @@ sub bass {
     get_scale_MIDI( 'C', 2, 'pentatonic' ),
   );
 
-  $common{'tick.durations'} = [ ('hn') x 4 ];
+  my $duration = 'hn'; # half-note
+  my $repeats  = 4;    # four of 'em
+
+  $common{'tick.durations'} = [ ($duration) x $repeats ];
 
   my $bass = sub {
     set_chan_patch( $args{score}, 0, 35 );
 
-    for my $n ( 1 .. 4 ) {
+    for my $n ( 1 .. $repeats ) {
       my $pitch = $pitches[ int rand @pitches ];
-      $args{score}->n( 'hn', $pitch );
+      $args{score}->n( $duration, $pitch );
     }
   };
 
