@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play a MIDI score in real-time
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0303';
 
 use strict;
 use warnings;
@@ -180,7 +180,7 @@ MIDI::RtMidi::ScorePlayer - Play a MIDI score in real-time
 
 =head1 VERSION
 
-version 0.0302
+version 0.0303
 
 =head1 SYNOPSIS
 
@@ -302,12 +302,15 @@ Play a given MIDI score in real-time.
 
 Play a given MIDI score asynchronously.
 
+=head1 THANK YOU
+
+This code would not exist without the help of CPAN's JBARRETT (John
+Barrett AKA fuzzix).
+
 =head1 SEE ALSO
 
 Examples are the F<eg/*> files in this distribution.
 
-Also check out the F<t/01-methods.t> file for basic usage.
-
 L<MIDI::RtMidi::FFI::Device>
 
 L<MIDI::Util>
